@@ -66,7 +66,7 @@ learning_rate = float(input("Enter the learning rate: "))
 batch_size = int(input("Enter the batch size: "))
 
 wandb.login(key=api_key)
-wandb.init(project_name=project_name, run_name=run_name)
+wandb.init(project=project_name, name=run_name)
 wandb.config = {"learning_rate": learning_rate, "batch_size": batch_size}
 
 
